==> atmc-http-0.0.2.0014-sources.jar: com/digiwin/athena/atmc/http/domain/action/SubmitAction.java <==
package com.digiwin.athena.atmc.http.domain.action;


import com.fasterxml.jackson.annotation.JsonIgnore;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.apache.commons.collections.CollectionUtils;

import java.io.Serializable;
import java.util.List;
import java.util.Map;
import java.util.Objects;

/**
 * Action实体定义
 * @author zhujg
 */
@Data
@NoArgsConstructor
@AllArgsConstructor
@Builder
public class SubmitAction extends Action implements Serializable {

    /**
     * 前端定义的ID
     *  confirm:提交 cancel 取消
     */
    private String id;

    /**
     * 前端定义的UI 类型使用到
     */
    private List<Object> backFills;

    private String url;

    /**
     * 默认ACTION
     */
    private boolean defaultAction;

    /**
     * 执行上下文
     */
    private SubmitExecuteContext executeContext;


    /**
     * 扩展参数，在需要做额外处理时可以使用
     */
    private Map<String,Object> extendParas;

    /**
     * 批量提交
     *   "isBatch": true,
     *   "schema": "purchase"
     */
    private Map<String,Object> batch;

    /**
     * 提交的数据源是什么
     *   "isBatch": true,
     *   "schema": "purchase"
     */
    private SubmitType submitType;

    /**
     * 目标状态
     */
    private String targetDataState;
    /**
     * 执行按扭时前端 执行的脚本
     */
    private String actionScript;

    private Object returnText;

    /**
     * 判断是否结束
     */
    private Map checkCompleteAction;

    /**
     * 在任务结束之后才执行
     */
    private Boolean executeAfterCheckCompleted;

    /**
     * 提交API 缺失显示字段
     */
    private List<Map<String,String>> addShowFileds;


    /**
     * 签核-可退回的任务ID列表
     */
    private List<String> startApproveActivity;

    /**
     * 要执行的附加Action，可以为null
     */
    private List<SubmitAction> attachActions;

    /**
     * 提交数据 特殊处理
     */
    private List<Map> submitProcessors;

    /**
     * 按钮显示顺序，数字越小越显示在页面右侧
     */
    private Integer order;


    /**
     * 提交的数据schema集合，不指定表示提交全部数据
     * <br>指定后，提交时只提交指定的数据
     */
    private List<String> submitSchemas;


    @JsonIgnore
    private SubmitAction mergeDataAction;

    /**
     * 是否需要压缩
     */
    private Boolean needCompress = false;

    public boolean isTaskEngin(){
        if (CollectionUtils.isNotEmpty(this.getAttachActions())) {
            for (SubmitAction attachAction : attachActions) {
                if (attachAction.isTaskEngin()) {
                    return true;
                }
            }
        }
       return  Objects.equals("WF", this.getCategory())
               || Objects.equals("TaskEngine", this.getCategory());
    }

    /**
     * 是否包含PTM的action
     * @return
     */
    public boolean isContainsPTM(){
        if (CollectionUtils.isNotEmpty(this.getAttachActions())) {
            for (SubmitAction attachAction : attachActions) {
                if (attachAction.isContainsPTM()) {
                    return true;
                }
            }
        }
        return  Objects.equals("PTM", this.getCategory());
    }

    /**
     * 是否会关闭任务卡
     *
     * @return
     */
    public boolean needCloseTask() {
        if (isTaskEngin()) {
            return true;
        } else if (Objects.equals("ATMC_API_EXECUTE_ERROR", this.getCategory())) {
            return true;
        } else if (Objects.equals("MANUAL_TASK", this.getCategory())) {
            return true;
        } else if( Objects.equals("UIBOT", this.getCategory())
                && Objects.equals("uibot_retrive", this.getActionId())){
            return true;
        }

        if (CollectionUtils.isNotEmpty(this.getAttachActions())) {
            for (SubmitAction attachAction : attachActions) {
                if (attachAction.needCloseTask()) {
                    return true;
                }
            }
        }
        return false;
    }

    @Override
    public String toString(){
        return String.format("%s ----- %s ----  %s",id,getActionId(),returnText);
    }
}

==> atmc-http-0.0.2.0054-sources.jar: com/digiwin/athena/atmc/http/domain/action/SubmitAction.java <==
package com.digiwin.athena.atmc.http.domain.action;


import com.fasterxml.jackson.annotation.JsonIgnore;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.apache.commons.collections.CollectionUtils;

import java.io.Serializable;
import java.util.List;
import java.util.Map;
import java.util.Objects;

/**
 * Action实体定义
 * @author zhujg
 */
@Data
@NoArgsConstructor
@AllArgsConstructor
@Builder
public class SubmitAction extends Action implements Serializable {

    /**
     * 前端定义的ID
     *  confirm:提交 cancel 取消
     */
    private String id;

    /**
     * 前端定义的UI 类型使用到
     */
    private List<Object> backFills;

    private String url;

    /**
     * 默认ACTION
     */
    private boolean defaultAction;

    /**
     * 执行上下文
     */
    private SubmitExecuteContext executeContext;


    /**
     * 扩展参数，在需要做额外处理时可以使用
     */
    private Map<String,Object> extendParas;

    /**
     * 批量提交
     *   "isBatch": true,
     *   "schema": "purchase"
     */
    private Map<String,Object> batch;

    /**
     * 提交的数据源是什么
     *   "isBatch": true,
     *   "schema": "purchase"
     */
    private SubmitType submitType;

    /**
     * 目标状态
     */
    private String targetDataState;
    /**
     * 执行按扭时前端 执行的脚本
     */
    private String actionScript;

    private Object returnText;

    /**
     * 判断是否结束
     */
    private Map checkCompleteAction;

    /**
     * 在任务结束之后才执行
     */
    private Boolean executeAfterCheckCompleted;

    /**
     * 提交API 缺失显示字段
     */
    private List<Map<String,String>> addShowFileds;


    /**
     * 签核-可退回的任务ID列表
     */
    private List<String> startApproveActivity;

    /**
     * 要执行的附加Action，可以为null
     */
    private List<SubmitAction> attachActions;

    /**
     * 提交数据 特殊处理
     */
    private List<Map> submitProcessors;

    /**
     * 按钮显示顺序，数字越小越显示在页面右侧
     */
    private Integer order;


    /**
     * 提交的数据schema集合，不指定表示提交全部数据
     * <br>指定后，提交时只提交指定的数据
     */
    private List<String> submitSchemas;


    @JsonIgnore
    private SubmitAction mergeDataAction;

    /**
     * 是否需要压缩
     */
    private Boolean needCompress = false;

    /**
     * 是否增量地提交，如果不是增量，name提交的是全部数据
     */
    private Boolean enableCombinedPost = true;
    /**
     * action执行结果
     */
    private ExecuteResult executeResult;

    /**
     * action是否执行过
     */
    private Boolean executed;
    /**
     * action是否支持重试
     */
    private Boolean supportRetry;

    /**
     * 转派——调用应用接口转派失败是否阻断
     */
    private Boolean needBlock;

    private List<SubmitAction> actionList;

    /**
     *  业务熟悉字段
     */
    private BusinessConfig businessConfig;

    public boolean isTaskEngin(){
        if (CollectionUtils.isNotEmpty(this.getAttachActions())) {
            for (SubmitAction attachAction : attachActions) {
                if (attachAction.isTaskEngin()) {
                    return true;
                }
            }
        }
       return  Objects.equals("WF", this.getCategory())
               || Objects.equals("TaskEngine", this.getCategory()) || Objects.equals("workflow", this.getCategory());
    }

    /**
     * 是否包含PTM的action
     * @return
     */
    public boolean isContainsPTM(){
        if (CollectionUtils.isNotEmpty(this.getAttachActions())) {
            for (SubmitAction attachAction : attachActions) {
                if (attachAction.isContainsPTM()) {
                    return true;
                }
            }
        }
        return  Objects.equals("PTM", this.getCategory());
    }

    /**
     * 是否会关闭任务卡
     *
     * @return
     */
    public boolean needCloseTask() {
        if (isTaskEngin()) {
            return true;
        } else if (Objects.equals("ATMC_API_EXECUTE_ERROR", this.getCategory())) {
            return true;
        } else if (Objects.equals("MANUAL_TASK", this.getCategory())) {
            return true;
        } else if( Objects.equals("UIBOT", this.getCategory())
                && Objects.equals("uibot_retrive", this.getActionId())){
            return true;
        }

        if (CollectionUtils.isNotEmpty(this.getAttachActions())) {
            for (SubmitAction attachAction : attachActions) {
                if (attachAction.needCloseTask()) {
                    return true;
                }
            }
        }
        return false;
    }

    @Override
    public String toString(){
        return String.format("%s ----- %s ----  %s",id,getActionId(),returnText);
    }
}
